@@ -1,12 +1,10 @@
 from __future__ import annotations
 
 from einspect.structs import PyLongObject
-from einspect.structs.deco import struct
 
 __all__ = ("PyBoolObject",)
 
 
-@struct
 class PyBoolObject(PyLongObject):
     """
     Defines a PyBoolObject Structure.
